@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c 11289 2009-02-16 23:48:56Z callum $ */
+/* $Id$ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -398,14 +398,14 @@ update_finish (WeatherInfo *info, gpointer data)
     if (gw_applet->gweather_pref.update_enabled)
     {
 	gw_applet->timeout_tag =
-		g_timeout_add (
-                       gw_applet->gweather_pref.update_interval * 1000,
+		g_timeout_add_seconds (
+                       gw_applet->gweather_pref.update_interval,
                         timeout_cb, gw_applet);
 
         nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
         if (nxtSunEvent >= 0)
             gw_applet->suncalc_timeout_tag =
-                        g_timeout_add (nxtSunEvent * 1000,
+                        g_timeout_add_seconds (nxtSunEvent,
                                 suncalc_timeout_cb, gw_applet);
     }
 
